<div align="center">
<h2>
  Yolov7-Pip: Packaged version of the Yolov7 repository  
</h2>
<h4>
    <img width="500" alt="teaser" src="docs/paper.png">
</h4>
</div>

## <div align="center">Overview</div>

This repo is a packaged version of the [Yolov7](https://github.com/WongKinYiu/yolov7) model.
### Installation
```
pip install yolov7detect
```

### Yolov7 Inference
```python

```
### Citation
```bibtex
@article{wang2022yolov7,
  title={{YOLOv7}: Trainable bag-of-freebies sets new state-of-the-art for real-time object detectors},
  author={Wang, Chien-Yao and Bochkovskiy, Alexey and Liao, Hong-Yuan Mark},
  journal={arXiv preprint arXiv:2207.02696},
  year={2022}
}
```
